import base64
from app.device_types.models import DeviceType
from app.utils import create_thumbnail, base4_image
from math import ceil
def handle_image_upload(image):
    if image:
        image_file, logo_content_type = create_thumbnail(image)
        if image_file:
            image_data = base64.b64encode(image_file.read()).decode('utf-8')
            return image_data, logo_content_type
    return None, None
def get_device_type_by_id(device_type_id):
    return DeviceType.query.filter_by(device_type_id=device_type_id).first()
def serialize_device_type(device_type):
    return {
        'id': device_type.device_type_id,
        'device_type_name': device_type.device_type_name,
        'measured_power': device_type.measured_power,
        'logo': base4_image(device_type.logo) if device_type.logo else "",
        'logo_content_type': device_type.logo_content_type,
    }
def paginate_query(query, page, per_page):
    paginated_data = query.paginate(page=page, per_page=per_page, error_out=False)
    total_count = paginated_data.total
    total_pages = ceil(total_count / per_page)
    start_index = (page - 1) * per_page + 1
    end_index = min(page * per_page, total_count)
    return paginated_data, total_count, total_pages, start_index, end_index
def get_filtered_device_types(search=None):
    query = DeviceType.query.filter(DeviceType.measured_power != 0)
    if search:
        query = query.filter(DeviceType.device_type_name.ilike(f'%{search}%'))
    return query.all()